@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.10
--- Copyright (C) 2011  Toni Gundogdu
+-- libquvi-scripts v0.4.16
+-- Copyright (C) 2011,2013  Toni Gundogdu <legatvs@gmail.com>
 -- Copyright (C) 2010 quvi project
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -61,7 +61,7 @@ function parse(self)
                     or error ("no match: media title")
 
     self.id = page:match('key:%s+"(.-)"')
-                or error ("no match: media id")
+                or error ("no match: media ID")
 
     self.thumbnail_url = page:match('"og:image" content="(.-)"') or ''
 
@@ -72,7 +72,7 @@ function parse(self)
                                      FunnyOrDie.choose_default,
                                      FunnyOrDie.to_s)
                         or error("unable to choose format")
-    self.url      = {format.url or error('no match: media url')}
+    self.url      = {format.url or error('no match: media stream URL')}
     return self
 end
 
@@ -82,26 +82,24 @@ end
 
 function FunnyOrDie.iter_formats(page)
     local t = {}
-    for u in page:gmatch("'src',%s+'(.-)'") do
-        local q,c = u:match('(%w+)%.(%w+)$')
-        table.insert(t, {url=u, quality=q, container=c})
---        print(u,c)
+    for u in page:gmatch('source src="(.-)"') do
+        table.insert(t,u)
     end
-    return t
-end
-
-function FunnyOrDie.choose_best(formats) -- Last is 'best'
-    local r = FunnyOrDie.choose_default(formats)
-    for _,v in pairs(formats) do
-        r = v
+    table.remove(t,1) -- Remove the first: the URL for segmented videos
+    local r = {}
+    for _,u in pairs(t) do
+        local q,c = u:match('/(%w+)%.(%w+)$')
+        table.insert(r, {url=u, quality=q, container=c})
     end
     return r
 end
 
-function FunnyOrDie.choose_default(formats) -- First is 'default'
-    for _,v in pairs(formats) do
-        return v
-    end
+function FunnyOrDie.choose_best(formats)
+    return FunnyOrDie.choose_default(formats)
+end
+
+function FunnyOrDie.choose_default(formats)
+    return formats[1]
 end
 
 function FunnyOrDie.to_s(t)
