@@ -1,5 +1,5 @@
 
--- libquvi-scripts v0.4.10
+-- libquvi-scripts v0.4.16
 -- Copyright (C) 2010-2011  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
@@ -46,6 +46,36 @@ function M.slash_unescape (s)
     return s
 end
 
+function M.base64_decode(s)
+    local itbl='ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/'
+
+    s = s:gsub('[^' .. itbl .. '=]', '')
+
+    return (s:gsub('.', function(x)
+        local r = ''
+
+        if (x ~= '=') then
+            local f = (itbl:find(x) - 1)
+
+            for i = 6, 1, -1 do
+                r = r .. (f % 2 ^ i - f % 2 ^ (i - 1) > 0 and '1' or '0')
+            end
+        end
+
+        return r;
+    end):gsub('%d%d%d?%d?%d?%d?%d?%d?', function(x)
+        local c = 0
+
+        if (#x == 8) then
+            for i = 1, 8 do
+                c = c + (x:sub(i, i) == '1' and 2 ^ (8 - i) or 0)
+            end
+        end
+
+        return string.char(c)
+    end))
+end
+
 -- handles
 --  Check whether a website script can "handle" the specified URL
 -- Params:
