@@ -1,6 +1,6 @@
 
--- libquvi-scripts v0.4.10
--- Copyright (C) 2010-2011  Toni Gundogdu <legatvs@gmail.com>
+-- libquvi-scripts v0.4.16
+-- Copyright (C) 2010-2011,2013  Toni Gundogdu <legatvs@gmail.com>
 --
 -- This file is part of libquvi-scripts <http://quvi.sourceforge.net/>.
 --
@@ -61,13 +61,16 @@ end
 function parse(self)
     self.host_id = "spiegel"
 
+    local p = quvi.fetch(self.page_url)
+
+    self.title = p:match('"module%-title">(.-)</')
+                    or p:match('"og:title".-content="(.-)%s+%-%s+SP')
+                      or error('no match: media title')
+
+    self.thumbnail_url = p:match('"og:image" content="(.-)"') or ''
+
     Spiegel.get_media_id(self)
 
-    local p = Spiegel.get_playlist(self)
-
-    self.title = p:match("<headline>(.-)</")
-                  or error ("no match: media title")
-
     local config  = Spiegel.get_config(self)
     local formats = Spiegel.iter_formats(config)
 
@@ -92,15 +95,6 @@ function Spiegel.get_media_id(self)
                 or error ("no match: media id")
 end
 
-function Spiegel.get_playlist(self)
-    local fmt_s = "http://www1.spiegel.de/active/playlist/fcgi/playlist.fcgi/"
-               .. "asset=flashvideo/mode=id/id=%s"
-
-    local playlist_url = string.format(fmt_s, self.id)
-
-    return quvi.fetch(playlist_url, {fetch_type = 'playlist'})
-end
-
 function Spiegel.get_config(self)
     local fmt_s      = "http://video.spiegel.de/flash/%s.xml"
     local config_url = string.format(fmt_s, self.id)
@@ -138,15 +132,8 @@ function Spiegel.choose_best(formats) -- Highest quality available
     return r
 end
 
-function Spiegel.choose_default(formats) -- Lowest quality available
-    local r = {width=0xffff, height=0xffff, bitrate=0xffff, url=nil}
-    local U = require 'quvi/util'
-    for _,v in pairs(formats) do
-        if U.is_lower_quality(v,r) then
-            r = v
-        end
-    end
-    return r
+function Spiegel.choose_default(formats)
+    return formats[1]
 end
 
 function Spiegel.to_s(t)
